## Examples Notebooks

|Notebook Name|Description|
|:-|:-|
|[Colaboratory.ipynb](https://github.com/iwasakishuto/Translation-Gummy/blob/master/examples/Colaboratory.ipynb)    [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/iwasakishuto/Translation-Gummy/blob/master/examples/Colaboratory.ipynb)                                                      | A notebook that anyone can easily use. |
|[Create.a.templates.ipynb](https://github.com/iwasakishuto/Translation-Gummy/blob/master/examples/Create.a.templates.ipynb)                                              | How to make a PDF template. |
|[Generate.a.PDF.through.gateway.ipynb](https://github.com/iwasakishuto/Translation-Gummy/blob/master/examples/Generate.a.PDF.through.gateway.ipynb)                      | How to generate a PDF using gateway. |
|[Generate.a.PDF.without.gateway.ipynb](https://github.com/iwasakishuto/Translation-Gummy/blob/master/examples/Generate.a.PDF.without.gateway.ipynb)                      | How to generate a PDF without gateway. |
|[Make.a.new.JournalCrawler.soup.ipynb](https://github.com/iwasakishuto/Translation-Gummy/blob/master/examples/Make.a.new.JournalCrawler.soup.ipynb)                      | How to make a new `JournalCrawler` whose `crawl_type` is `"soup"`. |
|[Make.a.new.URL.conversion.method.ipynb](https://github.com/iwasakishuto/Translation-Gummy/blob/master/examples/Make.a.new.URL.conversion.method.ipynb)                  | How to make a new url conversion method (`get_tex_url`, `get_soup_url`, `get_pdf_url`) for a particular `JournalCrawler`. |
|[Make.a.new._pass2journal.ipynb](https://github.com/iwasakishuto/Translation-Gummy/blob/master/examples/Make.a.new._pass2journal.ipynb)                                  | How to make a new method ( `_pass2journal` ) using gateway for a particular journal. |
|[[Docker] Use.Translation-Gummy.via.Docker.ipynb](https://github.com/iwasakishuto/Translation-Gummy/blob/master/examples/%5BDocker%5D%20Use.Translation-Gummy.via.Docker.ipynb)| Usage and output results when building an environment using [![Docker file](https://img.shields.io/badge/%F0%9F%90%B3-Dockerfile-0db7ed?style=flat-radius)](https://github.com/iwasakishuto/Translation-Gummy/blob/master/docker/Dockerfile) |
